pub struct Extension { /* private fields */ }Implementations
Sourceimpl Extension
impl Extension
String of the plugin author
Sourcepub fn description(&self) -> String
pub fn description(&self) -> String
String short description of the plugin
Sourcepub fn license_text(&self) -> String
pub fn license_text(&self) -> String
String complete license text for the given plugin
Sourcepub fn minimum_version_info(&self) -> VersionInfo
pub fn minimum_version_info(&self) -> VersionInfo
Minimum version info the plugin was tested on
Sourcepub fn maximum_version_info(&self) -> VersionInfo
pub fn maximum_version_info(&self) -> VersionInfo
Maximum version info the plugin will support
Sourcepub fn versions(&self) -> Array<ExtensionVersion>
pub fn versions(&self) -> Array<ExtensionVersion>
Metadata for all available versions of this plugin
Sourcepub fn current_version(&self) -> ExtensionVersion
pub fn current_version(&self) -> ExtensionVersion
Metadata for the currently selected version of this plugin
Sourcepub fn latest_version_id(&self) -> String
pub fn latest_version_id(&self) -> String
Latest version id available for this platform
Sourcepub fn project_url(&self) -> String
pub fn project_url(&self) -> String
String URL of the plugin’s git repository
Sourcepub fn package_url(&self) -> String
pub fn package_url(&self) -> String
String URL of the plugin’s git repository
String URL of the plugin author’s url
Sourcepub fn path(&self) -> PathBuf
pub fn path(&self) -> PathBuf
Relative path from the base of the repository to the actual plugin
Sourcepub fn subdir(&self) -> PathBuf
pub fn subdir(&self) -> PathBuf
Optional sub-directory the plugin code lives in as a relative path from the plugin root
Sourcepub fn dependencies(&self) -> String
pub fn dependencies(&self) -> String
Dependencies required for installing this plugin
Sourcepub fn dependencies_for_version(&self, version_id: &str) -> String
pub fn dependencies_for_version(&self, version_id: &str) -> String
Dependencies required for installing a specific version of this plugin
Sourcepub fn dependency_conflicts(&self) -> Vec<PluginDependencyConflict>
pub fn dependency_conflicts(&self) -> Vec<PluginDependencyConflict>
Dependency conflicts with installed plugins
Sourcepub fn dependency_conflicts_for_version(
&self,
version_id: &str,
) -> Vec<PluginDependencyConflict>
pub fn dependency_conflicts_for_version( &self, version_id: &str, ) -> Vec<PluginDependencyConflict>
Dependency conflicts with installed plugins for a specific plugin version
Sourcepub fn is_installed(&self) -> bool
pub fn is_installed(&self) -> bool
true if the plugin is installed, false otherwise
Sourcepub fn is_listed(&self) -> bool
pub fn is_listed(&self) -> bool
true if the plugin is present in its repository’s latest successful listing
Sourcepub fn is_deprecated(&self) -> bool
pub fn is_deprecated(&self) -> bool
true if the plugin is marked deprecated by its repository
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
true if the plugin is enabled, false otherwise
pub fn status(&self) -> PluginStatus
Sourcepub fn types(&self) -> Array<PluginType>
pub fn types(&self) -> Array<PluginType>
List of PluginType enumeration objects indicating the plugin type(s)
Sourcepub fn enable(&self, force: bool) -> bool
pub fn enable(&self, force: bool) -> bool
Enable this plugin, optionally trying to force it. Force loading a plugin with ignore platform and api constraints.
pub fn disable(&self) -> bool
Sourcepub fn install_dependencies(&self) -> bool
pub fn install_dependencies(&self) -> bool
Attempt to install the dependencies of this plugin
Sourcepub fn install_dependencies_for_version(&self, version_id: &str) -> bool
pub fn install_dependencies_for_version(&self, version_id: &str) -> bool
Attempt to install the dependencies of a specific version of this plugin
Sourcepub fn install_dependencies_for_version_with_exclusions(
&self,
version_id: &str,
excluded_package_names: &[&str],
) -> bool
pub fn install_dependencies_for_version_with_exclusions( &self, version_id: &str, excluded_package_names: &[&str], ) -> bool
Attempt to install the dependencies of a specific version of this plugin, excluding some packages by canonical name
Sourcepub fn cancel_uninstall(&self) -> bool
pub fn cancel_uninstall(&self) -> bool
Cancel an uninstall that is pending until restart.
pub fn updated(&self, version_id: &str) -> bool
pub fn repository(&self) -> String
Sourcepub fn is_being_deleted(&self) -> bool
pub fn is_being_deleted(&self) -> bool
Boolean status indicating that the plugin is being deleted
Sourcepub fn is_being_updated(&self) -> bool
pub fn is_being_updated(&self) -> bool
Boolean status indicating that the plugin is being updated
Sourcepub fn is_running(&self) -> bool
pub fn is_running(&self) -> bool
Boolean status indicating that the plugin is currently running
Sourcepub fn is_update_pending(&self) -> bool
pub fn is_update_pending(&self) -> bool
Boolean status indicating that the plugin has updates will be installed after the next restart
Sourcepub fn is_disable_pending(&self) -> bool
pub fn is_disable_pending(&self) -> bool
Boolean status indicating that the plugin will be disabled after the next restart
Sourcepub fn is_delete_pending(&self) -> bool
pub fn is_delete_pending(&self) -> bool
Boolean status indicating that the plugin will be deleted after the next restart
Sourcepub fn is_updated_available(&self) -> bool
pub fn is_updated_available(&self) -> bool
Boolean status indicating that the plugin has updates available
Sourcepub fn are_dependencies_being_installed(&self) -> bool
pub fn are_dependencies_being_installed(&self) -> bool
Boolean status indicating that the plugin’s dependencies are currently being installed
Sourcepub fn project_data(&self) -> String
pub fn project_data(&self) -> String
Gets a json object of the project data field